@@ -13,18 +13,28 @@ from utilities.forms import (
     DynamicModelChoiceField, APISelect,
 )
 
-from netbox_storage.models import Partition, PhysicalVolume, VolumeGroup
+from netbox_storage.models import Partition, PhysicalVolume, VolumeGroup, Drive
 
 
 class PhysicalVolumeForm(NetBoxModelForm):
     """Form for creating a new PhysicalVolume object."""
+    drive = DynamicModelChoiceField(
+        queryset=Drive.objects.all(),
+        label="Drive",
+        required=False,
+        widget=APISelect(
+            attrs={"data-url": reverse_lazy("plugins-api:netbox_storage-api:drive-list")}
+        ),
+        help_text="The Drive e.g. Hard Drive 1",
+    )
     partition = DynamicModelChoiceField(
         queryset=Partition.objects.all(),
         label="Partition",
+        required=False,
         widget=APISelect(
             attrs={"data-url": reverse_lazy("plugins-api:netbox_storage-api:partition-list")}
         ),
-        help_text="The Partition of the Drive e.g. Partition 1",
+        help_text="The Partition of the Drive e.g. /dev/sdc1",
     )
     pv_name = CharField(
         label="Physical Volume Name",
@@ -33,6 +43,7 @@ class PhysicalVolumeForm(NetBoxModelForm):
     vg = DynamicModelChoiceField(
         queryset=VolumeGroup.objects.all(),
         label="VG Name",
+        required=False,
         widget=APISelect(
             attrs={"data-url": reverse_lazy("plugins-api:netbox_storage-api:volumegroup-list")}
         ),
@@ -44,10 +55,29 @@ class PhysicalVolumeForm(NetBoxModelForm):
         help_text="Short Description e.g. Partition 1 on SSD Cluster",
     )
 
+    fieldsets = (
+        (
+            "Storage Configuration",
+            (
+                "drive",
+                "partition",
+            ),
+        ),
+        (
+            "Physical Volume Configuration",
+            (
+                "pv_name",
+                "vg",
+                "description",
+            ),
+        ),
+    )
+
     class Meta:
         model = PhysicalVolume
 
         fields = (
+            "drive",
             "partition",
             "pv_name",
             "vg",
