@@ -39,7 +39,7 @@ class Drive(NetBoxModel):
         ordering = ["size"]
 
     def __str__(self):
-        return f"VM: {self.virtual_machine} {self.identifier} Size: {self.size} GB Storage Cluster: {self.cluster}"
+        return f"VM: {self.virtual_machine} ({self.identifier}-{self.size}GB-{self.cluster})"
 
     def get_absolute_url(self):
         return reverse("plugins:netbox_storage:drive", kwargs={"pk": self.pk})
@@ -61,6 +61,9 @@ class Drive(NetBoxModel):
     def partition_count(self):
         return Partition.objects.filter(drive=self).count()
 
+    def device_name(self):
+        return f"/dev/sd{chr(ord('`') + int(self.identifier[-1]))}"
+
 
 class Partition(NetBoxModel):
     drive = models.ForeignKey(
@@ -186,9 +189,9 @@ class PhysicalVolume(NetBoxModel):
         "description",
     ]
 
-    prerequisite_models = (
-        'netbox_storage.VolumeGroup',
-    )
+    #prerequisite_models = (
+    #    'netbox_storage.VolumeGroup',
+    #)
 
     def get_absolute_url(self):
         return reverse("plugins:netbox_storage:physicalvolume", kwargs={"pk": self.pk})
