@@ -14,6 +14,9 @@ class PhysicalVolumeBaseTable(NetBoxTable):
     partition = tables.Column(
         linkify=True
     )
+    pv_name = tables.Column(
+        linkify=True
+    )
     description = tables.Column(
         linkify=True
     )
@@ -32,7 +35,7 @@ class PhysicalVolumeTable(PhysicalVolumeBaseTable):
             "description",
         )
         default_columns = (
-            "partition",
+            "pv_name",
             "description",
         )
 
