@@ -53,7 +53,7 @@ from netbox_storage.views import (
     LogicalVolumeBulkEditView,
     LogicalVolumeBulkDeleteView,
     LogicalVolumeView,
-    LogicalVolumeDeleteView,
+    LogicalVolumeDeleteView, VolumeGroupPhysicalVolumeListView,
 )
 
 app_name = "netbox_storage"
@@ -148,6 +148,9 @@ urlpatterns = [
         name="volumegroup_changelog",
         kwargs={"model": VolumeGroup},
     ),
+    path("volumegroup/<int:pk>/physicalvolume/",
+         VolumeGroupPhysicalVolumeListView.as_view(),
+         name="volumegroup_physicalvolumes"),
     #
     # LogicalVolume urls
     #
